@@ -209,6 +209,13 @@
     rtn
 }
 
+# return a list from ..., omitting any that pmatch omit
+.zap.args = function(..., omit) {
+    args = list(...)
+    args[!is.na(pmatch(names(args), omit))] = NULL
+    args
+}
+
 # return updated object with option list AND dot list
 .update.options = function(object, options, ...) {
     if (!is.list(options))
@@ -338,3 +345,96 @@ model.frame = function(formula, data, ...) {
     X[lti] = lt
     X
 }
+
+### submodel support...
+
+# Compact a model matrix
+# This returns just the R part of X's QR decomposition.
+# This is sufficient in lieu of the whole model matrix
+# Ideally, X is already a qr object in which case weights is assumed already incorporated
+# assign should be right if input is generated by model.matrix() or is $qr slot of lm
+#' @export
+.cmpMM = function(X, weights = diag(nrow(X)), assign = attr(X$qr, "assign")) {
+    if(!is.qr(X)) {
+        if(any(is.na(X)))
+            return(NULL)
+        if (!missing(weights))
+            X = suppressWarnings(diag(sqrt(weights)) %*% X)
+        X = try(qr(X), silent = TRUE)
+        if (inherits(X, "try-error"))
+            return(NULL)
+    }
+    R = qr.R(X, complete = FALSE)
+    R[, X$pivot] = R
+    colnames(R)[X$pivot] = colnames(R)
+    attr(R, "assign") = assign
+    R
+}
+
+# Get 'factors' table and simplify it (remove function calls from term labels)
+.smpFT = function(trms) {
+    tbl = attr(trms, "factors")
+    rn = rownames(tbl)
+    newrn = sapply(rn, function(x) all.vars(as.formula(paste("~", x)))[1])
+    if (any(newrn != rn)) {
+        rownames(tbl) = newrn
+        colnames(tbl) = apply(tbl, 2, function(x) paste(newrn[x > 0], collapse = ":"))
+    }
+    tbl
+}
+
+# Alias matrix. Goal here is to find indexes
+#    i1 = indices of columns of smaller model
+#    i2 = indices of all other terms
+# Then for a given linear hypothesis L_R %*% bhat_R (_R subscripts smaller model)
+#    we have L_R %*% bhat_R = L_R %*% (A %*% bhat_F) = (L_R %*% A) %*% bhat_F
+#    (where _F subscripts full model).
+# Moreover, L_R is just columns i1 of the linfct for the effect of interest.
+.alias.matrix = function(object, submodel) {
+    X = object@model.info$model.matrix  # assumed to have attributes "factors" and "assign"
+    if (is.character(X)) {  # model.matrix is a message
+        if (nchar(X) > 0) warning(X, call. = FALSE)
+        return(NULL)
+    }
+    assign = attr(X, "assign")
+    if (is.null(assign)) {  ### either missing model matrix or assign attribute
+        warning("submodel information is not available for this object", call. = FALSE)
+        return(NULL)
+    }
+    tbl = attr(X, "factors")
+    if (is.character(submodel)) {
+        type2 = pmatch(submodel[1], "type2", nomatch = 0) # 1 if type2, 0 otherwise
+        submodel = as.formula(paste("~", paste(names(object@levels), collapse="*")))
+    }
+    else
+        type2 = 0
+    # now submodel is a formula
+    # create term labels in compatible factor order
+    subtbl = attr(terms(update(object@model.info$terms, submodel)), "factors")
+    com = intersect(rownames(tbl), rownames(subtbl))
+    if(length(com) == 0) { # No matching factors at all
+        com = 1; 
+        subtbl = matrix(0)
+    }
+    sublab = apply(subtbl[com, , drop = FALSE], 2, function(x) paste(com[x > 0], collapse = ":"))
+    usecols = intersect(colnames(tbl), sublab)
+    incl = c(0, which(colnames(tbl) %in% usecols))
+    if (type2) {
+        incl = max(incl)  # just the last one
+        overlap = apply(tbl, 2, function(x) sum(x * tbl[, incl]))
+        zaplist = which(overlap < sum(tbl[, incl])) # don't contain our term
+        i0 = which(assign %in% c(0, zaplist))
+    }
+    else
+        i0 = integer(0)
+    rcols = which(assign %in% incl)
+    if (length(i0) > 0) {
+        X[, rcols] = qr.resid(qr(X[, i0, drop = FALSE]), X[, rcols, drop = FALSE])
+        X[, i0] = 0
+    }
+    A = qr.coef(qr(X[, rcols, drop = FALSE]), X)  # alias matrix
+    A[is.na(A)] = 0  ## NA coefs are really ones constrained to zero
+    attr(A, "rcols") = rcols   # cols in submodel
+    attr(A, "submodstr") = paste(colnames(tbl)[incl], collapse = " + ")
+    A
+}
